Commit ebb3c506fd880a383ea66679865e16e24253cb3a

Vicent Marti 2014-03-03T12:40:25

features: Rename `_HAS_` to `_FEATURE_`

diff --git a/src/settings.c b/src/settings.c
index 644e71c..9308f94 100644
--- a/src/settings.c
+++ b/src/settings.c
@@ -21,13 +21,13 @@ int git_libgit2_features()
 {
 	return 0
 #ifdef GIT_THREADS
-		| GIT_HAS_THREADS
+		| GIT_FEATURE_THREADS
 #endif
 #if defined(GIT_SSL) || defined(GIT_WINHTTP)
-		| GIT_HAS_HTTPS
+		| GIT_FEATURE_HTTPS
 #endif
 #if defined(GIT_SSH)
-		| GIT_HAS_SSH
+		| GIT_FEATURE_SSH
 #endif
 	;
 }
diff --git a/tests/core/features.c b/tests/core/features.c
index b8c9003..3ce02f4 100644
--- a/tests/core/features.c
+++ b/tests/core/features.c
@@ -12,20 +12,20 @@ void test_core_features__0(void)
 	caps = git_libgit2_features();
 
 #ifdef GIT_THREADS
-	cl_assert((caps & GIT_HAS_THREADS) != 0);
+	cl_assert((caps & GIT_FEATURE_THREADS) != 0);
 #else
-	cl_assert((caps & GIT_HAS_THREADS) == 0);
+	cl_assert((caps & GIT_FEATURE_THREADS) == 0);
 #endif
 
 #if defined(GIT_SSL) || defined(GIT_WINHTTP)
-	cl_assert((caps & GIT_HAS_HTTPS) != 0);
+	cl_assert((caps & GIT_FEATURE_HTTPS) != 0);
 #else
-	cl_assert((caps & GIT_HAS_HTTPS) == 0);
+	cl_assert((caps & GIT_FEATURE_HTTPS) == 0);
 #endif
 
 #if defined(GIT_SSH)
-	cl_assert((caps & GIT_HAS_SSH) != 0);
+	cl_assert((caps & GIT_FEATURE_SSH) != 0);
 #else
-	cl_assert((caps & GIT_HAS_SSH) == 0);
+	cl_assert((caps & GIT_FEATURE_SSH) == 0);
 #endif
 }
diff --git a/include/git2/common.h b/include/git2/common.h
index 7effc8d..4b3e02e 100644
--- a/include/git2/common.h
+++ b/include/git2/common.h
@@ -98,26 +98,26 @@ GIT_EXTERN(void) git_libgit2_version(int *major, int *minor, int *rev);
  * was compiled
  */
 typedef enum {
-	GIT_HAS_THREADS	= (1 << 0),
-	GIT_HAS_HTTPS = (1 << 1),
-	GIT_HAS_SSH = (1 << 2),
+	GIT_FEATURE_THREADS	= (1 << 0),
+	GIT_FEATURE_HTTPS = (1 << 1),
+	GIT_FEATURE_SSH = (1 << 2),
 } git_feature_t;
 
 /**
  * Query compile time options for libgit2.
  *
  * @return A combination of GIT_HAS_* values.
  *
- * - GIT_HAS_THREADS
+ * - GIT_FEATURE_THREADS
  *   Libgit2 was compiled with thread support. Note that thread support is
  *   still to be seen as a 'work in progress' - basic object lookups are
  *   believed to be threadsafe, but other operations may not be.
  *
- * - GIT_HAS_HTTPS
+ * - GIT_FEATURE_HTTPS
  *   Libgit2 supports the https:// protocol. This requires the openssl
  *   library to be found when compiling libgit2.
  *
- * - GIT_HAS_SSH
+ * - GIT_FEATURE_SSH
  *   Libgit2 supports the SSH protocol for network operations. This requires
  *   the openssh to be found when compiling libgit2
  */
@@ -98,26 +98,26 @@ GIT_EXTERN(void) git_libgit2_version(int *major, int *minor, int *rev);
  * Query compile time options for libgit2.
  *
- * @return A combination of GIT_HAS_* values.
+ * @return A combination of GIT_FEATURE_* values.
  *